@@ -13,6 +13,7 @@ Includes:
 - 70-80% performance improvement for up-to-date projects
 
 ## Skill Invocation Guide (English-Only)
+# mypy: disable-error-code=return-value
 
 ### Related Skills
 - **moai-foundation-trust**: For post-update validation
@@ -37,6 +38,7 @@ Includes:
    - Use backup to restore previous state
    - Debug with `python -m moai_adk doctor --verbose`
 """
+# type: ignore
 
 from __future__ import annotations
 
@@ -707,7 +709,7 @@ def _build_template_context(
         "PROJECT_DESCRIPTION": project_description,
         "PROJECT_VERSION": project_version,
         "CREATION_TIMESTAMP": created_at,
-        "HOOK_PROJECT_DIR": hook_project_dir,
+        "PROJECT_DIR": hook_project_dir,
         "CONVERSATION_LANGUAGE": language_config.get("conversation_language", "en"),
         "CONVERSATION_LANGUAGE_NAME": language_config.get("conversation_language_name", "English"),
         "CODEBASE_LANGUAGE": project_section.get("language", "generic"),
