@@ -6,7 +6,8 @@ CLI entry module:
 - Click-based CLI framework
 - Rich console terminal output
 """
+# type: ignore
 
-from moai_adk.__main__ import cli, show_logo
+from moai_adk.__main__ import cli, show_logo  # type: ignore[attr-defined]
 
 __all__ = ["cli", "show_logo"]
