@@ -67,7 +67,7 @@ class TemplateProcessor:
 
         # Detect common template variables and provide helpful suggestions
         common_variables = {
-            "HOOK_PROJECT_DIR": "Cross-platform hook path (update moai-adk to fix)",
+            "PROJECT_DIR": "Cross-platform hook path (run /alfred:0-project to set)",
             "PROJECT_NAME": "Project name (run /alfred:0-project to set)",
             "AUTHOR": "Project author (run /alfred:0-project to set)",
             "CONVERSATION_LANGUAGE": "Interface language (run /alfred:0-project to set)",
