@@ -220,7 +220,7 @@ def main() -> None:
     try:
         # Read JSON payload from stdin (for compatibility)
         input_data = sys.stdin.read()
-        data = json.loads(input_data) if input_data.strip() else {}
+        _data = json.loads(input_data) if input_data.strip() else {}
 
         # Generate enhanced session output
         session_output = format_session_output()
